# DATA FOR Identifying trait-based tolerance to sediment dynamics during seedling establishment across eight mangrove species

Authors:
Publication doi:

## General description
Data and analysis underlying the results published in the paper titled 'Identifying trait-based tolerance to sediment dynamics during seedling establishment across eight mangrove species
' in Limnology and Oceanography (doi to be added). The data was collected during a mesocosm experiment carried out in 2019 with south Chinese mangrove species to test their tolerance to sediment dynamics.

## Files
#### Analysis
* analysis.R

#### Main data files
* survival.csv
* growth.csv
* finalmeasurements.csv

#### Supplemenatary data files
* deadseedlings.csv
* ongoingCEDkandelia.csv

## File descriptions
### General 
* species = mangrove species (AC = Aegiceras corniculatum, AM = ...)
* treatment = sediment treatment applied, cumulative (over the course of the experiment) (-6 = cumulative 6 cm erosion, -2 cm/week; 0 = control; +3 = cumulative 3 cm accretion, +1 cm/week)
* day = experiment day (see Fig. 2 in accompanying paper)

### analysis.R
Contains all the code to generate all figures in the main text and supplementary information of the accompanying paper. 

### survival.csv
Contains the survival data monitored during the experiment.
* day = experiment day 
* species = mangrove species 
* treatment = sediment treatment applied
* potnumber = replicate, we tested 12 seedlings per species per treatment
* seedlingID = seedling identifier
* potID = pot identifier
* state = survival state (0 = dead, 1 = toppled, 2 = alive)

### growth.csv
Growth data of each seedling over the course of the experiment. 
* day = experiment day 
* species = mangrove species
* treatment = sediment treatment applied
* potnumber = replicate, we tested 12 seedlings per species per treatment
* seedlingID = seedling identifier
* potID = pot identifier
* length_cm = length measured from sediment layer to tip of seedling
* cum_sed_treatment_cm = cumulative sediment treatment up until the experiment day of length measurement
* true_length_cm = length_cm + cum_sed_treatment_cm for alive seedlings; length_cm for dead seedlings
* timestep = days between current and previous measurement
* growth_cm = growth in cm between current and previous measurement
* growthrate = growth_cm/timestep

### finalmeasurements.csv
Data measured at the end of the experiment, including a CED (critical erosion depth) test (described in accompanying paper). 
* seedlingID = seedling identifier
* potnumber = replicate, we tested 12 seedlings per species per treatment
* species = mangrove species
* treatment = sediment treatment applied
* pioneerrank = succesional stage; 1 = pioneer, 2 = mid-successional, 3 = climax species
* vivipary = 0 = non-viviparous, 1 = cryptoviviparous, 3 = viviparous 
* proplength_cm = propagule length, measured at start of experiment
* propweight_g = propagule weigth, data sources described in accompanying paper
* maxshoot_cm = maximum shoot length of seedling reached at the end of the experiment
* maxroot_cm = maximum root length (length of longest root) reached at the end of the experiment
* nr_roots = number of primary roots counted on seedling at the end of the experiment
* CEDtopple_cm = erosion depth at which seedling toppled during CED test
* CEDdislodge_cm = erosion depth at which seedling became fully dislodged during CED test
* above_g = weight of oven-dried aboveground biomass
* root_g = weight of oven-dried belowground (root) biomass
* above_cm3 = total volume of aboveground biomass, estimated from photos using ImageJ
* root_cm3 = total volume of belowground biomass, estimated from photos using ImageJ

### deadseedlings.csv
Used to generate Supplementary Information Fig. S3. 
* species = mangrove species
* treatment = seidment treatment applied
* cumtreat_cm = cumulative sediment treatment up until the experiment day of length measurement
* potnumber = replicate, we tested 12 seedlings per species per treatment
* day = experiment day on data was collected
* stateID = survival state (0 = dead, 1 = toppled, 2 = alive)
* state = state, written out
* maxshoot_cm = maximum shoot length of seedling reached at the end of the experiment
* nr_roots = number of primary roots counted on seedling at the end of the experiment
* maxroot_cm = maximum root length (length of longest root) reached at the end of the experiment
* seedlingID = seedling identifier

### ongoingCEDkandelia.csv
Used to generate Supplementary Information Fig. S10. Seperate experiment where *Kandelia* propagules were sowed either horizontally or vertically. Every 4 or 5 days, we carried out a CED test for 2 horizontal (stranded) and 2 vertical (planted) seedlings.
* day = experiment day 
* type = sowing type; planted = vertical, stranded = placed horizontally
* CED_cm = erosion depth at which seedling became fully dislodged during CED test
* longestroot_cm = maximum root length (length of longest root) reached at the end of the experiment
* nr_roots = number of primary roots counted on seedling at the end of the experiment
* species = mangrove species
* shoot_cm = maximum shoot length of seedling reached at the end of the experiment